@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 #include "config.h"
@@ -207,9 +207,9 @@ void XLALFrameUFrameHFree(LALFrameUFrameH * frame)
     FRAME_LIBRARY_SELECT_VOID(XLALFrameUFrameHFree, frame);
 }
 
-LALFrameUFrameH *XLALFrameUFrameHAlloc(const char *name, double start, double dt, int frnum)
+LALFrameUFrameH *XLALFrameUFrameHAlloc(const char *name, double start1, double start2, double dt, int frnum)
 {
-    FRAME_LIBRARY_SELECT_NULL(XLALFrameUFrameHAlloc, name, start, dt, frnum);
+    FRAME_LIBRARY_SELECT_NULL(XLALFrameUFrameHAlloc, name, start1, start2, dt, frnum);
 }
 
 LALFrameUFrameH *XLALFrameUFrameHRead(LALFrameUFrFile * stream, int pos)
@@ -322,6 +322,11 @@ int XLALFrameUFrChanSetTimeOffset(LALFrameUFrChan * channel, double timeOffset)
     FRAME_LIBRARY_SELECT(XLALFrameUFrChanSetTimeOffset, channel, timeOffset);
 }
 
+int XLALFrameUFrChanSetTRange(LALFrameUFrChan * channel, double tRange)
+{
+    FRAME_LIBRARY_SELECT(XLALFrameUFrChanSetTRange, channel, tRange);
+}
+
 int XLALFrameUFrChanVectorAlloc(LALFrameUFrChan * channel, int dtype, size_t ndata)
 {
     FRAME_LIBRARY_SELECT(XLALFrameUFrChanVectorAlloc, channel, dtype, ndata);
